@@ -15,20 +15,25 @@ plot_snapshot <- local({
   function(incomplete = FALSE) {
     if (is.null(dev.list())) return(NULL)
 
-    mfg <- par("mfg")
-    if (identical(mfg, rep(1L, 4)) || incomplete) {
-      mfg_init <<- NULL
-      mfg_changed <<- FALSE
+    if (par_page) {
+      if (!incomplete && !par('page')) return(NULL)  # current page not complete
     } else {
-      # now there is a multi-col/row layout
-      if (is.null(mfg_init)) {
-        mfg_init <<- mfg
+      # a hack for R < 3.0.2
+      mfg <- par("mfg")
+      if (identical(mfg, rep(1L, 4)) || incomplete) {
+        mfg_init <<- NULL
+        mfg_changed <<- FALSE
       } else {
-        if (identical(mfg_init, mfg)) {
-          if (!mfg_changed) return(NULL)
+        # now there is a multi-col/row layout
+        if (is.null(mfg_init)) {
+          mfg_init <<- mfg
         } else {
-          mfg_changed <<- TRUE
-          return(NULL)
+          if (identical(mfg_init, mfg)) {
+            if (!mfg_changed) return(NULL)
+          } else {
+            mfg_changed <<- TRUE
+            return(NULL)
+          }
         }
       }
     }
@@ -64,10 +69,13 @@ is_par_change <- function(p1, p2) {
 
 # R 3.0 has significant changes in display lists
 isR3 <- getRversion() >= "3.0.0"
+# is page in par()? feature of R 3.0.2
+par_page <- "page" %in% getFromNamespace('.Pars', 'graphics')
 
 # if all calls are in these elements, the plot is basically empty
-empty_calls <- if (isR3) c("C_par", "C_layout", "palette", "palette2") else
-  c("layout", "par")
+empty_calls <- if (isR3) {
+  c("C_par", "C_layout", "palette", "palette2", "C_strWidth", "C_strHeight", "C_clip")
+} else c("layout", "par")
 
 is.empty <- function(x) {
   if(is.null(x)) return(TRUE)
